import abc
from typing import List
from regtester.RegExTestItem import RegExTestItem
import regex
import re
from re import RegexFlag
from typing import Pattern

class RegExTest(abc.ABC):

    def __init__(self) -> None:
        regex_str = self.get_regex()
        flags  = self.get_regex_flags()
        self.compiled_regex:Pattern = regex.compile(fr"{regex_str}",flags)

    @abc.abstractmethod
    def get_regex(self) -> str:
        pass

    @abc.abstractmethod
    def get_regex_flags(self)-> RegexFlag:
        pass
    
    @abc.abstractmethod
    def get_regex_name(self)-> str:
        pass
        
    @abc.abstractmethod
    def get_tests(self)-> List[RegExTestItem]:
        pass

    @abc.abstractmethod
    def exec_regex(self, regex:Pattern, text:str)-> any:
        pass

if __name__ == "__main__":
    x=RegExTest()


"""Setup for the chocobo package."""

import setuptools


with open('README.md') as f:
    README = f.read()

setuptools.setup(
    author="Thierno Ibrahima DIOP",
    author_email="thierno.diop@baamtu.com",
    name='regtester',
    license="MIT",
    description='RegEx Tester is a module to build unit test of regex in python',
    version='v0.4',
    long_description=README,
    url='https://github.com/bayethiernodiop/regtester',
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    install_requires=["regex==2019.11.1","colorama==0.4.1"],
    classifiers=[
        # Trove classifiers
        # (https://pypi.python.org/pypi?%3Aaction=list_classifiers)
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
    ],
)